==> wordpress-2.1.1-da_DK.tar.gz: wordpress/wp-includes/js/tinymce/themes/advanced/langs/da_dk.js <==
﻿// da_DK lang variables

tinyMCE.addToLang('',{
theme_style_select : '-- Styles --',
theme_code_desc : 'Rediger HTML-kilde',
theme_code_title : 'HTML kildeeditor',
theme_code_wordwrap : 'Ordombrydning',
theme_sub_desc : 'Subscript',
theme_sup_desc : 'Superscript',
theme_hr_desc : 'Indsæt horisontal linje',
theme_removeformat_desc : 'Fjern formatering',
theme_custom1_desc : 'Din personlige beskrivelse her',
insert_image_border : 'Ramme',
insert_image_dimensions : 'Størrelse',
insert_image_vspace : 'Vertikal afstand',
insert_image_hspace : 'Horisontal afstand',
insert_image_align : 'Justering',
insert_image_align_default : '-- Ikke sat --',
insert_image_align_baseline : 'Grundlinje',
insert_image_align_top : 'Top',
insert_image_align_middle : 'Midte',
insert_image_align_bottom : 'Bund',
insert_image_align_texttop : 'TextTop',
insert_image_align_absmiddle : 'Absolut Midte',
insert_image_align_absbottom : 'Absolut bund',
insert_image_align_left : 'Venstre',
insert_image_align_right : 'Højre',
theme_font_size : '-- Skriftstørrelse --',
theme_fontdefault : '-- Font family --',
theme_block : '-- Format --',
theme_paragraph : 'Paragraph',
theme_div : 'Div',
theme_address : 'Adresse',
theme_pre : 'Preformateret',
theme_h1 : 'Heading 1',
theme_h2 : 'Heading 2',
theme_h3 : 'Heading 3',
theme_h4 : 'Heading 4',
theme_h5 : 'Heading 5',
theme_h6 : 'Heading 6',
theme_blockquote : 'Blockquote',
theme_code : 'Kode',
theme_samp : 'Kodeeksempel',
theme_dt : 'Definitionsterm',
theme_dd : 'Definitionsbeskrivelse',
theme_colorpicker_title : 'Vælg en farve',
theme_colorpicker_apply : 'Anvend',
theme_forecolor_desc : 'Vælg tekstfarve',
theme_backcolor_desc : 'Vælg baggrundsfarve',
theme_charmap_title : 'Select custom character',
theme_charmap_desc : 'Insert custom character',
theme_visualaid_desc : 'Toggle guidelines/invisible elements',
insert_anchor_title : 'Insert/edit anchor',
insert_anchor_name : 'Anchor name',
theme_anchor_desc : 'Insert/edit anchor',
theme_insert_link_titlefield : 'Title',
theme_clipboard_msg : 'Copy/Cut/Paste is not available in Mozilla and Firefox.\nDo you want more information about this issue?',
theme_path : 'Path',
cut_desc : 'Klip',
copy_desc : 'Kopier',
paste_desc : 'Indsæt',
link_list : 'Linkliste',
image_list : 'Billedeliste',
browse : 'Gennemse',
image_props_desc : 'Billedegenskaber',
newdocument_desc : 'Nyt dokument',
class_name : 'Class',
newdocument : 'Are you sure you want clear all contents?',
about_title : 'Om TinyMCE',
about : 'About',
license : 'License',
plugins : 'Plugins',
plugin : 'Plugin',
author : 'Author',
version : 'Version',
loaded_plugins : 'Loaded plugins',
help : 'Help',
not_set : '-- Not set --',
close : 'Close',
toolbar_focus : 'Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X',
invalid_data : 'Error: Invalid values entered, these are marked in red.'
});

==> wordpress-2.2.1-da_DK.tar.gz: wordpress/wp-includes/js/tinymce/themes/advanced/langs/da_dk.js <==
﻿// da_DK lang variables

tinyMCE.addToLang('',{
theme_style_select : '-- Styles --',
theme_code_desc : 'Rediger HTML-kilde',
theme_code_title : 'HTML kildeeditor',
theme_code_wordwrap : 'Ordombrydning',
theme_sub_desc : 'Subscript',
theme_sup_desc : 'Superscript',
theme_hr_desc : 'Indsæt horisontal linje',
theme_removeformat_desc : 'Fjern formatering',
theme_custom1_desc : 'Din personlige beskrivelse her',
insert_image_border : 'Ramme',
insert_image_dimensions : 'Størrelse',
insert_image_vspace : 'Vertikal afstand',
insert_image_hspace : 'Horisontal afstand',
insert_image_align : 'Justering',
insert_image_align_default : '-- Ikke sat --',
insert_image_align_baseline : 'Grundlinje',
insert_image_align_top : 'Top',
insert_image_align_middle : 'Midte',
insert_image_align_bottom : 'Bund',
insert_image_align_texttop : 'TextTop',
insert_image_align_absmiddle : 'Absolut Midte',
insert_image_align_absbottom : 'Absolut bund',
insert_image_align_left : 'Venstre',
insert_image_align_right : 'Højre',
theme_font_size : '-- Skriftstørrelse --',
theme_fontdefault : '-- Font family --',
theme_block : '-- Format --',
theme_paragraph : 'Paragraph',
theme_div : 'Div',
theme_address : 'Adresse',
theme_pre : 'Preformateret',
theme_h1 : 'Heading 1',
theme_h2 : 'Heading 2',
theme_h3 : 'Heading 3',
theme_h4 : 'Heading 4',
theme_h5 : 'Heading 5',
theme_h6 : 'Heading 6',
theme_blockquote : 'Blockquote',
theme_code : 'Kode',
theme_samp : 'Kodeeksempel',
theme_dt : 'Definitionsterm',
theme_dd : 'Definitionsbeskrivelse',
theme_colorpicker_title : 'Vælg en farve',
theme_colorpicker_apply : 'Anvend',
theme_forecolor_desc : 'Vælg tekstfarve',
theme_backcolor_desc : 'Vælg baggrundsfarve',
theme_charmap_title : 'Select custom character',
theme_charmap_desc : 'Insert custom character',
theme_visualaid_desc : 'Toggle guidelines/invisible elements',
insert_anchor_title : 'Insert/edit anchor',
insert_anchor_name : 'Anchor name',
theme_anchor_desc : 'Insert/edit anchor',
theme_insert_link_titlefield : 'Title',
theme_clipboard_msg : 'Copy/Cut/Paste is not available in Mozilla and Firefox.\nDo you want more information about this issue?',
theme_path : 'Path',
cut_desc : 'Klip',
copy_desc : 'Kopier',
paste_desc : 'Indsæt',
link_list : 'Linkliste',
image_list : 'Billedeliste',
browse : 'Gennemse',
image_props_desc : 'Billedegenskaber',
newdocument_desc : 'Nyt dokument',
class_name : 'Class',
newdocument : 'Are you sure you want clear all contents?',
about_title : 'Om TinyMCE',
about : 'About',
license : 'License',
plugins : 'Plugins',
plugin : 'Plugin',
author : 'Author',
version : 'Version',
loaded_plugins : 'Loaded plugins',
help : 'Help',
not_set : '-- Not set --',
close : 'Close',
toolbar_focus : 'Jump to tool buttons - Alt+Q, Jump to editor - Alt-Z, Jump to element path - Alt-X',
invalid_data : 'Error: Invalid values entered, these are marked in red.',
more_colors : 'More colors',
color_picker_tab : 'Picker',
color_picker : 'Color picker',
web_colors_tab : 'Web safe',
web_colors : 'Web safe colors',
named_colors_tab : 'Named',
named_colors : 'Named colors',
color : 'Color:',
color_name : 'Name:'
});
